==> hbase-server-1.1.1-sources.jar: org/apache/hadoop/hbase/constraint/ConstraintException.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase.constraint;

import org.apache.hadoop.hbase.classification.InterfaceAudience;

/**
 * Exception that a user defined constraint throws on failure of a 
 * {@link org.apache.hadoop.hbase.client.Put}.
 * <p>Does <b>NOT</b> attempt the 
 * {@link org.apache.hadoop.hbase.client.Put} multiple times, 
 * since the constraint<it>should</it> fail every time for the same 
 * {@link org.apache.hadoop.hbase.client.Put} (it should be idempotent).
 */
@InterfaceAudience.Private
public class ConstraintException extends org.apache.hadoop.hbase.DoNotRetryIOException {
  private static final long serialVersionUID = 1197446454511704140L;

  public ConstraintException() {
    super();
  }

  public ConstraintException(String msg)
  {
    super(msg);
  }
  
  
  public ConstraintException(String msg, Throwable cause) {
    super(msg, cause);
  }
}

==> hbase-server-2.1.3-sources.jar: org/apache/hadoop/hbase/constraint/ConstraintException.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hbase.constraint;

import org.apache.yetus.audience.InterfaceAudience;

/**
 * Exception that a user defined constraint throws on failure of a
 *  {@link org.apache.hadoop.hbase.client.Put}.
 * <p>Does <b>NOT</b> attempt the
 *  {@link org.apache.hadoop.hbase.client.Put} multiple times, 
 *  since the constraint <b>should</b> fail every time for
 *  the same {@link org.apache.hadoop.hbase.client.Put} (it should be
 * idempotent).
 */
@InterfaceAudience.Private
public class ConstraintException extends org.apache.hadoop.hbase.DoNotRetryIOException {
  private static final long serialVersionUID = 1197446454511704140L;

  public ConstraintException() {
    super();
  }

  public ConstraintException(String msg)
  {
    super(msg);
  }
  
  
  public ConstraintException(String msg, Throwable cause) {
    super(msg, cause);
  }
}
